# OpenDR Hyperparameter Tuner

This folder contains a tool for performing hyperparameter tuning on any of the learners of the OpenDR toolkit.
This tool is based on [Optuna](https://optuna.org/) [[1]](#optuna-paper), a hyperparameter optimization framework.

#### References
<a name="optuna-paper" href="https://dl.acm.org/doi/10.1145/3292500.3330701">[1]</a>
Optuna: A Next-generation Hyperparameter Optimization Framework.,
[arXiv](https://arxiv.org/abs/1907.10902).  

